B-52s | Shop the B-52s Official Store
Description: B-52s Music,Downloadable Music,Clothing,Shirts,mp3s,Videos,DVDs,CDs,Gift Certificates,Gift Cards,Hats
Keywords: B 52s merchandise

Welcome, please log in to access your account.
Home | View Cart | Help
Sort:
B52s Rock Lobster Tee
Qty:
ROCK LOBSTER! This super-soft, black 100% cotton tee features the word ROCK, a classic lobster image and the B-52s logo printed in red. It practically screams "Let's Rock!" Down, down...
B-52s Planet Claire Tee
Qty:
This B-52s Planet Claire Tee from their hit 1979 single features the band in space suits and a shadow of "The B-52s" below. Indigo blue.
B52s 1st Album Tee
Qty:
The B-52s photo from their 1st album is printed on the front of this soft, grey, 100% cotton tee.
B-52s Skeleton Tee
Qty:
Skulls, Flowers, and B52s skeletal caricatures adorn the front of this tee! Printed on an ultra soft tee with a distressed vintage look. Be sure not to miss out on this one! Black 100% cotton.
B52s Logo Nailhead Ladies Tee
Qty:
B52s Logo Nailhead Ladies Tee features the classic B52s logo in a beautiful nailhead design. Black 100% cotton.
B-52s Zip Hoodie
Qty:
The B-52s is printed boldly in red on the front of this black hoody! Classic and a must have. Black 100% cotton.
B-52s 35th Anniversary Tee
Qty:
35 years and still dancing this mess around! In celebration of their 35th Anniversary year, the B-52s have put together this special commemorative tee! A burst graphic along with B-52s:35:2012 is printed on the front of this black, 100% cotton, slim-cut soft tee.
B-52s With The Wild Crowd-Live In Athens, GA DVD
Qty:
With The Wild Crowd-Live In Athens, GA is the first official B-52s live DVD, a sizzling set recorded in the band's hometown on February 11, 2011. The show marked the 34th anniversary of their first-ever concert on Valentine's Day 1977. Wig-wearing, boa-draped, glitter-covered fans came from near and far to celebrate this historic event, turning Athens' Classic Center into a cosmic dancehall. This DVD includes the classics "Love Shack," "Rock Lobster," "Give Me Back My Man," "Funplex," "Roam," "Planet Claire," "Party Out Of Bounds," "Mesopotamia" and many many more.
B-52s With The Wild Crowd-Live In Athens, GA CD
$9.99
Qty:
With The Wild Crowd-Live In Athens, GA is the first official B-52s live album, a sizzling set recorded in the band's hometown on February 11, 2011. The show marked the 34th anniversary of their first-ever concert on Valentine's Day 1977. Wig-wearing, boa-draped, glitter-covered fans came from near and far to celebrate this historic event, turning Athens' Classic Center into a cosmic dancehall. This CD includes the classics "Love Shack," "Rock Lobster," "Give Me Back My Man," "Funplex," "Roam," "Planet Claire," "Party Out Of Bounds," "Mesopotamia" and many many more.
B-52s Electronic Gift Certificate
Qty:
Give a great gift this holiday season with an Electronic B-52s Gift Certificate!
1. Select the desired denomination below, and add to your shopping cart. An electronic gift certificate will be sent via email to you or a friend.
2. Set a delivery date for the gift email during the check-out process. You can choose to have the gift certificate sent immediately, or designate a date in the future (a birthday, for example).
3. The recipient will receive a customized email which will inform them of the gift. They will also be provided their account number and instructions.
4. To make a purchase using the certificate, all the recipient has to do is visit theb52s.com, and enter the STORE. After adding the desired items to their shopping cart, all they will need to do is enter the code (provided in the gift certificate email) as payment.
Terms & Conditions
This certificate is valid in theB52s.com store and any associated pre-order, when available. Gift certificates are valid for 3 years from the date of purchase. Gift certificates are treated as currency, so recipients will be eligible for any sale or special promotions that may be available at the time the certificates are redeemed.
Description:
Quantity:
Price:
Cart Quantity:
Cart Subtotal:
Shopping Cart
Items in Cart: 0
Browse The Store
Mailing List
Join Our Mailing List
Questions or concerns?
Online Help | Email Customer Service
877-MUSIC77 [877-687-4277]
949-333-4820 (International)
M-Th 9am - 12am EST
Fri 9am - 8pm EST
Home | View Cart | Help | Privacy Policy | Terms of Use | Site Map
Live Nation Merchandise
Copyright © 2014 B-52s
Discover is not accepted in all stores.
Close
Drag Items Here

Bundle Savings:
Total: $0.00

- Continue

Close
Your Bundle

Price:

- Proceed to Checkout

- Continue Shopping

Return To Bundle Builder